#
# spec file for package python-manuel
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013-2018 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15allpythons}
Name:           python-manuel
Version:        1.13.0
Release:        1.1
Summary:        Python module to build tested documentation
License:        Apache-2.0
URL:            https://pypi.org/project/manuel/
# SourceRepository: https://github.com/benji-york/manuel
Source:         https://files.pythonhosted.org/packages/source/m/manuel/manuel-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if 0%{?suse_version} >= 1600
# SECTION Documentation requirements:
BuildRequires:  python3-Sphinx
BuildRequires:  python3-myst-parser
BuildRequires:  python3-sphinxcontrib-copybutton
# /SECTION
%endif
# SECTION Testing requirements:
BuildRequires:  %{python_module zope.testing}
# /SECTION
%python_subpackages

%description
Manuel lets the user build tested documentation.

Documentation, a full list of included plug-ins, and examples are available
with the -doc package and at http://packages.python.org/manuel/.

%package        doc
Summary:        Build tested documentation

%description    doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n manuel-%{version}

%build
%pyproject_wheel
%if 0%{?suse_version} >= 1600
sphinx-build -c sphinx/ -a src/manuel docs/
rm docs/.buildinfo
%endif

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%if 0%{?suse_version} >= 1600
%{python_expand #
mkdir -p %{buildroot}%{_docdir}/%{$python_prefix}-manuel-doc
cp -r docs/* %{buildroot}%{_docdir}/%{$python_prefix}-manuel-doc
%fdupes %{buildroot}%{_docdir}/%{$python_prefix}-manuel-doc
}
%endif

%check
%pytest src/manuel/tests.py

%files %{python_files}
%license LICENSE.rst
%doc CHANGES.rst COPYRIGHT.rst PKG-INFO README.rst
%{python_sitelib}/manuel
%{python_sitelib}/manuel-%{version}.dist-info

%if 0%{?suse_version} >= 1600
%files %{python_files doc}
%doc %{_docdir}/%{python_prefix}-manuel-doc
%endif

%changelog
* Fri Feb  7 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.13.0
  * Include*.md files in wheel These are needed by the test suite,
    which is also included in the wheel.
  * Fix tests on python3.11
  * Update some web links
  * Update pyinstaller to 6.1.0 for python >= 3.11 support
  * doctest: use outputchecker argument also in debug mode. Fixes #38
  * Remove references to old "six" module
- Drop python-manuel-no-six.patch, merged upstream
* Tue Feb  6 2024 Markéta Machová <mmachova@suse.com>
- Build also on the old python3 (needed by some packages in the Backports).
* Tue Jan 16 2024 Markéta Machová <mmachova@suse.com>
- Add %%{?sle15_python_module_pythons}
- Don't build the docs in SLE-based projects
* Tue May  2 2023 Ben Greiner <code@bnavigator.de>
- Replace unsupported setuptoos sphinx_build hook
- Remove six and setuptools from requirements metadata
* Tue Jan  3 2023 Ben Greiner <code@bnavigator.de>
- Fix doc build: primary python not in buildset for backports
  15.4_py39
- Move to PEP517
* Mon Oct 17 2022 pgajdos@suse.com
- added patches
  fix https://github.com/benji-york/manuel/issues/33
  + python-manuel-no-six.patch
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.12.4 (2022-06-24)
  * Remove silly PyPI version badge.
- Update to 1.12.3 (2022-06-24)
  * Modernize internal project structure; drop tox; no user-visible changes (hopefully).
  * Rework coverage badge generation.
  * Drop Travis CI badge (the project is using GitHub for CI now)
- Update to 1.11.2 (2022-05-15)
  * Fix missing file in release.
- Update to 1.11.1 (2022-05-14)
  * Fix brown-bag release.
- Update to 1.11.0 (2022-05-14)
  * Fix test detection in Python 2 which was broken since 1.10.0. (#20)
  * Add Python 3.9 and 3.10 to tox config.
  * Add a Makefile to centeralized development activities.
* Mon May 31 2021 pgajdos@suse.com
- %%check: use %%pytest rpm macro
* Thu Dec  3 2020 Benjamin Greiner <code@bnavigator.de>
- Fix Sphinx build with primary python3 flavor for
  gh#openSUSE/python-rpm-macros#66
- Reorganize BuildRequires
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Drop unnecessary Require.
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.1:
  * Support for pypy3
  * Support for python 3.7
* Wed Feb 28 2018 hpj@urpla.net
- update to version 1.9.0:
  * You can now use Manuel with the nose and pytest test runners by
    defining Manuel tests inside unittest.TestCase classes.
  * Added support for Python 3.5 and Python 3.6.
  * Dropped support for Python 2.6
- add a fixed conf.py in order to properly build the docs (again)
* Fri Jun 23 2017 aloisio@gmx.com
- Converted to single-spec
* Thu May  7 2015 benoit.monin@gmx.fr
- update to version 1.8.0:
  * Fixed ResourceWarnings under Python 3.
  * Added support for PyPy and Python 3.4.
  * Drop official support for Python 3.1 and 3.2.
  * Fix odd ImportError problems when used with tox and coverage.
  * Fix parsing of reST codeblock options with hyphens.
- rename documentation files .txt to .rst: changed upstream
* Sat Aug  3 2013 hpj@urpla.net
- version 1.7.2: initial build
